import React from "react";
import { NestedSchemaEditor, TransTitle, extractValue, memo, updateValue } from "@ui-schema/ui-schema";
import { List } from 'immutable';
import { ValidityHelperText } from "../Component/LocaleHelperText";
import { IconPlus, IconMinus } from "@ui-schema/ds-bootstrap/Component/Icons";
const SimpleList = extractValue(memo(({
  storeKeys,
  ownKey,
  schema,
  value,
  onChange,
  showValidity,
  errors,
  required
}) => {
  let btnSize = schema.getIn(['view', 'btnSize']) || 'small';
  let classFormGroup = ["form-group", "d-flex", "align-items-center"];
  let classFormControl = ["form-control"];

  if (showValidity && errors.size) {
    classFormControl.push('is-invalid');
  }

  if (showValidity && !errors.size) {
    classFormGroup.push('was-validated');
  }

  return React.createElement(React.Fragment, null, React.createElement(TransTitle, {
    schema: schema,
    storeKeys: storeKeys,
    ownKey: ownKey
  }), React.createElement("div", null, value ? value.map((val, i) => React.createElement("div", {
    key: i,
    className: classFormGroup.join(' ')
  }, React.createElement(NestedSchemaEditor, {
    className: classFormControl.join(' '),
    showValidity: showValidity,
    storeKeys: storeKeys.push(i),
    schema: schema.get('items'),
    required: required,
    noGrid: true
  }), React.createElement("div", null, React.createElement(IconMinus, {
    btnSize: btnSize,
    onClick: () => {
      onChange(updateValue(storeKeys, value.splice(i, 1)));
    }
  })))).valueSeq() : null, React.createElement("div", null, React.createElement(IconPlus, {
    btnSize: btnSize,
    onClick: () => {
      onChange(updateValue(storeKeys, value ? value.push('') : List([''])));
    }
  }))), React.createElement(ValidityHelperText
  /* only pass down errors which are not for a specific sub-schema */
  , {
    errors: errors.filter(err => List.isList(err) ? !err.getIn([1, 'arrayItems']) : true),
    showValidity: showValidity,
    schema: schema
  }));
}));
export { SimpleList };